@@ -921,6 +921,9 @@ def get_pricing(
         fields = ["close"]
     if isinstance(symbol_list, str):
         symbol_list = [symbol_list]
+    if isinstance(symbol_list, list) and "sp500" in symbol_list:
+        symbol_list.remove("sp500")
+        symbol_list += SP500_SYMBOLS
 
     fields = [f.lower() for f in fields]
     bad = [f for f in fields if f not in ALLOWED_FIELDS]
@@ -928,25 +931,32 @@ def get_pricing(
         raise ValueError(f"Invalid field(s): {bad}. Allowed: {sorted(ALLOWED_FIELDS)}")
 
     # --------------------------------------------------------------- download
-    DATASETS = [
-        ("Stocks-Daily-Price", extend),
-        ("ETFs-Daily-Price", extend),
-        ("Cryptocurrencies-Daily-Price", extend),
-        ("Bonds-Daily-Price", extend),
-        ("Commodities-Daily-Price", extend),
-        ("Forex-Daily-Price", extend),
-        ("Indices-Daily-Price", False),  # indices generally have no proxy data
-    ]
-    remaining = set(symbol_list)  # symbols still to fetch
+    universe = ds.load_dataset(
+        "paperswithbacktest/Universe-Daily-Price",
+        token=_get_hf_token(),
+    )
+    mapping = universe["train"].to_pandas()
+    mapping = mapping.set_index("symbol")["repo_id"].to_dict()
+
+    grouped = defaultdict(list)
+    remaining = []
+    for sym in symbol_list:
+        repo_id = mapping.get(sym)
+        repo_id = repo_id.split("/")[1] if isinstance(repo_id, str) else None
+        if repo_id:
+            grouped[repo_id].append(sym)
+        else:
+            print(f"Warning: No dataset found for symbol '{sym}'")
+            remaining.append(sym)
+
     frames = []
-    for dataset_name, ext_flag in DATASETS:
-        if not remaining:  # all symbols resolved → stop early
-            break
-        df_part = load_dataset(dataset_name, list(remaining), extend=ext_flag)
+    for repo_id, syms in grouped.items():
+        ext_flag = extend if repo_id != "Indices-Daily-Price" else False
+        df_part = load_dataset(repo_id, syms, extend=ext_flag)
         if not df_part.empty:
             frames.append(df_part)
-            remaining -= set(df_part["symbol"].unique())
-    df = pd.concat(frames, ignore_index=True)
+
+    df = pd.concat(frames, ignore_index=True) if frames else pd.DataFrame()
 
     df["date"] = pd.to_datetime(df["date"])
     df.set_index("date", inplace=True)
